/* mlm_remora.c
 *
 * CallCommander Integration for a Logitek Remora control surface.
 *
 *   (C) Copyright 2002-2007 Fred Gleason <fredg@paravelsystems.com>
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as
 *   published by the Free Software Foundation; either version 2 of
 *   the License, or (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public
 *   License along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * This is a sample CallCommander Logic Module.  All it does is print
 * a message to stdout for each callback.  (To see the messages, be sure 
 * to specify a Log Path in MDbAdmin->ManageLogicModules).
 *
 * To compile this module, just do:
 * 
 *   gcc -shared -o mlm_remora.mlm mlm_remora.c
 */

/*
 * Site Definitions -- Customize these values for your site!
 */
#define SUPERVISOR_ADDRESS "supervisor0.radioamerica.org"
#define VGUEST_PROFILE_NAME "cc-b"
#define VGUEST_PROFILE_PASSWORD "letmein"
#define VGUEST_HYBRID0_ENGINE 3
#define VGUEST_HYBRID0_DEVICE 0x000F
#define VGUEST_HYBRID1_ENGINE 3
#define VGUEST_HYBRID1_DEVICE 0x0010
#define VGUEST_FADER1_ENGINE 3
#define VGUEST_FADER1_DEVICE 0x000B

#include <stdio.h>
#include <string.h>
#include <mlm/mlm.h>

/*
 * Globals
 */
int vguest_handle;
char caller_name[12][256];
char caller_city[12][256];
char caller_state[12][256];
char caller_station[12][256];
char caller_comment[12][1024];
char caller_textline[12][2][2048];
int caller_lstate[12];

void WriteLineEntry(int line)
{
  char label[1024];

  /*
   * First Text Line -- Name, City, State, Station
   */
  if(strlen(caller_name[line])>0) {
    sprintf(label,"%s ",caller_name[line]);
  }
  else {
    sprintf(label,"Name Unknown ");
  }
  if((strlen(caller_city[line])>0)||(strlen(caller_state[line])>0)) {
    sprintf(label+strlen(label),"- %s %s ",caller_city[line],caller_state[line]);
  }
  if(strlen(caller_station[line])>0) {
    sprintf(label+strlen(label),"- %s",caller_station[line]);
  }
  MLMVGuestWriteText(vguest_handle,VGUEST_FADER1_ENGINE,
		     VGUEST_FADER1_DEVICE+line,0,0,0,0,label);

  /*
   * Second Text Line -- Comment
   */
  MLMVGuestWriteText(vguest_handle,VGUEST_FADER1_ENGINE,
		     VGUEST_FADER1_DEVICE+line,0,1,0,0,caller_comment[line]);

  /*
   * Update Text Lines
   */
  strncpy(caller_textline[line][0],label,2048);
  strncpy(caller_textline[line][1],caller_comment[line],2048);
}


void ClearLineEntry(int line)
{
  int j;

    caller_name[line][0]=0;
    caller_city[line][0]=0;
    caller_state[line][0]=0;
    caller_station[line][0]=0;
    caller_comment[line][0]=0;
    for(j=0;j<2;j++) {
      caller_textline[line][j][0]=0;
    }
}


void MLMStartup()
{
  int i;
  int j;

  /*
   * Initialize Globals
   */
  for(i=0;i<12;i++) {
    caller_name[i][0]=0;
    caller_city[i][0]=0;
    caller_state[i][0]=0;
    caller_station[i][0]=0;
    caller_comment[i][0]=0;
    caller_lstate[i]=MLM_LINE_INACTIVE;
    for(j=0;j<2;j++) {
      caller_textline[i][j][0]=0;
    }
  }

  /*
   * Start ON Timer
   */
  MLMStartTimer(0,1000,MLM_TIMER_ONESHOT);

  /*
   * Initialize vGuest Connection
   */
  vguest_handle=MLMVGuestOpen(SUPERVISOR_ADDRESS,MLM_VGUEST_DEFAULT_TCP_PORT,
			      VGUEST_PROFILE_NAME,VGUEST_PROFILE_PASSWORD);
}


void MLMShutdown()
{
/*
  int i;

  for(i=0;i<4;i++) {
    MLMVGuestWriteText(vguest_handle,VGUEST_FADER1_ENGINE,
		       VGUEST_FADER1_DEVICE,0,i+48,0,
		       MLM_VGUEST_TEXT_DISPLAY_OVERWRITE|
		       MLM_VGUEST_TEXT_VIDEO_NORMAL|
		       MLM_VGUEST_TEXT_COLOR_WHITE," ");
    MLMVGuestWriteText(vguest_handle,VGUEST_FADER1_ENGINE,
		       VGUEST_FADER1_DEVICE+6,0,i+48,0,
		       MLM_VGUEST_TEXT_DISPLAY_OVERWRITE|
		       MLM_VGUEST_TEXT_VIDEO_NORMAL|
		       MLM_VGUEST_TEXT_COLOR_WHITE," ");
  }
*/
}


void MLMWatchdogStateChanged(int state)
{
}


void MLMShowChanged(const char *showname,int state)
{
}


void MLMConsoleChanged(int console,int mode)
{
}


void MLMLineStateChanged(int lstate,int line,int bank,int console)
{
  char label[8];

  sprintf(label,"Line %2d",line+1);
  switch(lstate) {
      case MLM_LINE_ONAIR:
      case MLM_LINE_LOCKED:
	/*
	 * Set Fader Label
	 */
/*
	switch(bank) {
	    case 0:
	      MLMVGuestWriteText(vguest_handle,VGUEST_HYBRID0_ENGINE,
				 VGUEST_HYBRID0_DEVICE,0,2,0,0,label);
	      break;

	    case 1:
	      MLMVGuestWriteText(vguest_handle,VGUEST_HYBRID1_ENGINE,
				 VGUEST_HYBRID1_DEVICE,0,2,0,0,label);
	      break;
	}
*/
	break;

      default:
	/*
	 * Set Fader Label
	 */
/*
	switch(bank) {
	    case 0:
	      MLMVGuestWriteText(vguest_handle,VGUEST_HYBRID0_ENGINE,
				 VGUEST_HYBRID0_DEVICE,0,2,0,0," ");
	      break;

	    case 1:
	      MLMVGuestWriteText(vguest_handle,VGUEST_HYBRID1_ENGINE,
				 VGUEST_HYBRID1_DEVICE,0,2,0,0," ");
	      break;
	}
*/
	break;
  }

  switch(lstate) {
      case MLM_LINE_INACTIVE:
      case MLM_LINE_IDLE:
	/*
	 * Clear Line Label
	 */
	ClearLineEntry(line);
	MLMVGuestWriteText(vguest_handle,VGUEST_FADER1_ENGINE,
			   VGUEST_FADER1_DEVICE+line,0,0,0,0," ");
	MLMVGuestWriteText(vguest_handle,VGUEST_FADER1_ENGINE,
			   VGUEST_FADER1_DEVICE+line,0,1,0,0," ");
	break;

      default:
	WriteLineEntry(line);
	break;
  }
  caller_lstate[line]=lstate;
}


void MLMDumpStateChanged(int state)
{
}


void MLMRecordStateChanged(int state)
{
}


void MLMBusyAllStateChanged(int state)
{
}


void MLMScreenStateChanged(int state)
{
}


void MLMMuteStateChanged(int state)
{
}


void MLMConferenceStateChanged(int state)
{
}


void MLMVipStateChanged(int state)
{
}


void MLMReceivedString(int elem,int line,const char *str)
{
}


void MLMCallerIdReceived(int line,const char *number)
{
}


void MLMChatMessageReceived(const char *name,const char *msg)
{
}


void MLMCallerElementReceived(int line,int elem,const char *str)
{
  switch(elem) {
      case MLM_ELEMENT_NAME:
	strncpy(caller_name[line],str,256);
	break;

      case MLM_ELEMENT_CITY:
	strncpy(caller_city[line],str,256);
	break;

      case MLM_ELEMENT_STATE:
	strncpy(caller_state[line],str,256);
	break;

      case MLM_ELEMENT_STATION:
	strncpy(caller_station[line],str,256);
	break;

      case MLM_ELEMENT_COMMENT:
	strncpy(caller_comment[line],str,1024);
	break;

      default:
	return;
  }
  WriteLineEntry(line);
}


void MLMUdpReceived(int handle,const char *data,int len)
{
}


void MLMSerialReceived(int handle,const char *data,int len)
{
}


void MLMTimerExpired(int timernum)
{
  int i;
  int j;

  switch(timernum) {
      case 0:  /* ON Timer */
	for(i=0;i<12;i++) {
	  switch(caller_lstate[i]) {
	      case MLM_LINE_ONAIR:
	      case MLM_LINE_LOCKED:
		for(j=0;j<2;j++) {
		  MLMVGuestWriteText(vguest_handle,VGUEST_FADER1_ENGINE,
				     VGUEST_FADER1_DEVICE+i,0,j,0,0,
				     caller_textline[i][j]);
		}
		break;
	  }
	}
	MLMStartTimer(1,1000,MLM_TIMER_ONESHOT);  /* OFF Timer */
	break;

      case 1:  /* OFF Timer */
	for(i=0;i<12;i++) {
	  switch(caller_lstate[i]) {
	      case MLM_LINE_ONAIR:
	      case MLM_LINE_LOCKED:
		for(j=0;j<2;j++) {
		  MLMVGuestWriteText(vguest_handle,VGUEST_FADER1_ENGINE,
				     VGUEST_FADER1_DEVICE+i,0,j,0,0," ");
		}
		break;
	  }
	}
	MLMStartTimer(0,200,MLM_TIMER_ONESHOT);  /* ON Timer */
	break;
  }
}


void MLMVGuestPulseReceived(int handle,int engine,int device,int surface,
			    int relay,int length)
{
}


void MLMVGuestTurnOnReceived(int handle,int engine,int device,int surface,
			     int bus)
{
}


void MLMVGuestTurnOffReceived(int handle,int engine,int device,int surface,
			      int bus)
{
}


void MLMVGuestSetInputAssignReceived(int handle,int dest_engine,
				     int dest_device,int surface,
				     int src_engine,int src_device)
{
}


void MLMVGuestSetInputModeReceived(int handle,int engine,int device,
				   int surface,int mode)
{
}


void MLMVGuestSetFaderLevelReceived(int handle,int engine,int device,
				    int surface,int level)
{
}
